# Error

An error occurred while processing your request.

**Error**: {error_message}

## Next Steps

- Check the request parameters and try again
- Use `katana://help` for guidance on available tools and usage

______________________________________________________________________

**Status**: Error
